c======================================================================
      subroutine mtcheck(nper,period,rho,pha,rhomax,rhomin,
     &                   phamax, phamin, wrho, wpha, * )
c======================================================================

      implicit none

      include 'misdat.inc'
      include 'ctrlblk.inc'
      include 'io.inc'

      integer i, nper
      real period(*), rho(*), pha(*), 
     &     rhomax(*), rhomin(*), phamax(*), phamin(*),
     &     wrho(*), wpha(*), temp


c======================================================================
c---check that all periods are positive
c   negative periods imply frequency, convert to period

      if( iprint.ge.5 ) then
        write(*,*)'MTCHECK entered with nper =', nper
        do i = 1, nper
          write(*,*) i, period(i), rho(i),pha(i),rhomax(i),rhomin(i),
     &               phamax(i), phamin(i), wrho(i), wpha(i)
        enddo
      endif

      do i = 1, nper
        if( period(i).lt.0. ) then
          period(i) = -1./period(i)
        else if( period(i).eq.0. ) then
          write(*,*) 'MTCHECK: zero period for i = ', i
          write(*,*)'         returning to main program'
          nper = -2
          return 1
        endif
      enddo

c---check that data in increasing period order
      if( period(1).lt.period(nper) ) then
        continue
      else
        if( iprint.gt.0 ) then
          write(*,*) ' MTCHECK: reversing the data arrays'
        endif
        call revers( nper, period )
        call revers( nper, rho )
        call revers( nper, pha )
        call revers( nper, rhomax )
        call revers( nper, rhomin )
        call revers( nper, phamax )
        call revers( nper, phamin )
        call revers( nper, wrho )
        call revers( nper, wpha )
      endif
 
c---check that periods are monotonically increasing
      do i = 1, nper-1
        if( period(i+1).le.period(i) ) then
          write(*,*)'MTCHECK: WARNING WARNING WARNING WARNING WARNING'
          write(*,*)'    periods not monotonically increasing' 
          write(*,*)'period(i), period(i+1)=',period(i), period(i+1)
        end if
      end do

c---check that rhomax and rhomin are positive
      do i = 1, nper
        if(rhomax(i).le.0.) rhomax(i) = MISDAT
        if(rhomin(i).le.0.) rhomin(i) = MISDAT
      end do

c---check for rho.gt.0. and for rhomax.ne.MISDAT & rhomin.ne.MISDAT
c    rhomax > rho > rhomin  
c    phamax > pha > phamin

      do i = 1, nper
        if( rho(i).gt.0. .and. rhomax(i).ne.MISDAT 
     &                   .and. rhomin(i).ne.MISDAT ) then
          if( rhomax(i).lt.rhomin(i) ) then
            temp = rhomax(i)
            rhomax(i) = rhomin(i)
            rhomin(i) = temp
          endif
          if( (rhomax(i).lt.rho(i) .or. rhomin(i).gt.rho(i)) .and.
     &        iprint.gt.0 ) then
            write(*,*) 'MTCHECK: rhomax > rho > rhomin not upheld'
            write(*,*) '        i,rhomax,rho,rhomin =',
     &                          i,rhomax(i),rho(i),rhomin(i) 
          endif

          if( pha(i).ne.MISDAT .and.
     &        phamax(i).ne.MISDAT .and. phamin(i).ne.MISDAT ) then
            if( phamax(i).lt.phamin(i) ) then
              temp = phamax(i)
              phamax(i) = phamin(i)
              phamin(i) = temp
            endif
            if( phamax(i).lt.pha(i) .or. phamin(i).gt.pha(i) .and.
     &        iprint.gt.0 ) then
              write(*,*) 'MTCHECK: phamax > pha > phamin not upheld'
              write(*,*) '        i,phamax,pha,phamin =',
     &                            i,phamax(i),pha(i),phamin(i)
            endif
          else
            phamax(i) = MISDAT
            phamin(i) = MISDAT
          endif
        endif
      enddo

      return
      end
