      subroutine mtread( fin, stat, type, nper, period, rho, pha,
     &           rhomax, rhomin, phamax, phamin, wrho, wpha, * )
 
c-----------------------------------------------------------------------
c
c routine to read in MT data in JONES format
c
c prompts for filename, station & data type (must be R__ or S__)
c
c TYPE:      RAV    -   Berdichevsky average (RXY+RYX)/2
c            RDE    -   Determinant average
c            REG    -   Egger's major eigenvalue
c            REP    -   Egger's positive eigenvalue
c            REM    -   Egger's negative eigenvalue
c
c            M??    -   model response
c
c if fin="*", then no prompting is done and file must already
c      have been opened
c
c NOTE: data always returned in increasing period order
c       error message if periods not monotonically increasing
c
c-----------------------------------------------------------------------
c
c     O/P
c      nper = 0    "0" answered for filename or no data, RETURN
c           = -1   "STOP" answered for filename, RETURN 1 made
c           = -2   Error return, RETURN 1 made
c           = -9   Trying to read transfer function in, RETURN
c
C-----------------------------------------------------------------------

      implicit none
 
      include 'MAXF.inc'
      include 'MISDAT.inc'
      include 'CTRLBLK.inc'
      include 'IO.inc'

c-----------------------------------------------------------------------
 
      real period(*), rho(*), pha(*), rhomax(*), rhomin(*),
     &     phamax(*), phamin(*), wrho(*), wpha(*)
      real per2(MAXF), rho2(MAXF), pha2(MAXF), rhomx2(MAXF),
     &     rhomn2(MAXF), phamx2(MAXF), phamn2(MAXF),
     &     wrho2(MAXF), wpha2(MAXF)
      real per3(MAXF), rho3(MAXF), pha3(MAXF), rhomx3(MAXF),
     &     rhomn3(MAXF), phamx3(MAXF), phamn3(MAXF),
     &     wrho3(MAXF), wpha3(MAXF)
      real per4(MAXF), rho4(MAXF), pha4(MAXF), rhomx4(MAXF),
     &     rhomn4(MAXF), phamx4(MAXF), phamn4(MAXF),
     &     wrho4(MAXF), wpha4(MAXF)
      real rdet, pdet, per, fxx, fxy, fyx, fyy, fzerr, fzdet
      character fin*(*), stat*6, type*3, statx*6, typex*3,
     &          null*1, bell*1, filext*20
      complex zdet, zxx, zxy, zyx, zyy
      integer nper, ilook, look, lfin, lfext, ioerr, i
      logical BERD, DET, EGG, EGGM, EGGP, MODEL

      character*50 SCCS_ID
 
      data SCCS_ID /"@(#)mtread.f     1.12     94/10/24\n"/
 
c----------------------------------------------------------------------- 

      ilook = 0

      null = char(0)
      bell = char(7)
      BERD = .FALSE.
      DET  = .FALSE.
      EGG  = .FALSE.
      EGGM = .FALSE.
      EGGP = .FALSE.

c-----------------------------------------------------------------------
C
C  SUBROUTINE TO READ IN MT RESPONSE FUNCTIONS IN STANDARD FORMAT
C

      call shiftup( stat )
      call shiftup( type )

      if( iprint.ge.5 ) then
        write(*,*)'MTREAD entered:'
        write(*,*)'          fin = ', fin 
        write(*,*)'         stat = ', stat 
        write(*,*)'         type = ', type 
      end if

c--fin=* file already open on unit ind1 (skip next few statements)
c
      if( fin.eq.'*' ) then
        rewind ind1
        look = 1
        goto 2
      end if
 
c--check if the first letter in the filename is a dot, ie. fin is
c   only a file extension 
c  prompt for the datafile, use fin as default
c  add on the extension if the filename given does not have a dot

      call trunc(fin,lfin)
      if(index(fin,'.').eq.1.and.lfin.lt.5)then
         filext = fin
         lfext=lfin
      endif
    1 call tin( 'Give mt datafile ("xx"=stop; "0"=no file)', fin )
      call shiftdown( fin )
      if( fin .eq. '0' ) then
        nper = 0
        return
      else if( fin .eq. 'xx' ) then
        nper = -1
        return 1
      end if
      if(index(fin,'.').eq.0.and.lfext.gt.0)then
         call trunc(fin,lfin)
         fin(lfin+1:)=filext(1:lfext)
      endif


c-- open mt data file

      open( unit=ind1, status='old', file=fin, err=9901, iostat=ioerr)


c--if i/p (passed) station code to search for is blank, generate it

      if( stat(1:1).eq.' ' .or. stat(1:1).eq.null ) then
         call trunc(fin, lfin)
         if(lfin.gt.1)then
            do i = lfin, 1, -1
               if(fin(i:i).eq.'/')then
                  stat = fin(i+1:min(lfin,i+7))
                  call shiftup(stat)
                  goto 5
               endif
            end do
            stat = fin(1:lfin)
            call shiftup(stat)
         endif
      end if
 
    5 call tin( 'Give station ("XXXXXX" to stop)', stat )
      call shiftup( stat )
      if( stat .eq. 'XXXXXX' ) return 1
 
      look = 1


c--top of search loop on station

    2 read( ind1, '(a6)', end = 9902 ) statx
      call shiftup( statx )
      if( iprint.ge.10 ) then
        write(*,*) 'MTREAD: line ', statx,' found looking for stat'
      endif
      if( stat .ne. statx ) goto 2

c--bottom of loop
 
      if( fin.eq.'*' ) then
        look = 2
        goto 12
      end if
 

c--determine type to read in, use type as default

    6 call tin( STAT//' located; type ("XXX"=stop'//
     &                                              ') >', type )
      call shiftup( type )
      if( type .eq. 'XXX' ) return 1
      if( type(1:1).eq.'T' ) then
        write( *,* ) ' You are trying to read a transfer',
     &               ' function in --- going to TFREAD'
        nper = -9
        return
      else if( type(1:1).ne.'R' .and. type(1:1).ne.'S'
     &                          .and. type(1:1).ne.'M' ) then
        write( *,* ) ' First character of TYPE must be the ',
     &               'letter "R" or "S" or "M", try again', bell
        goto 6
      end if
          
   12 if( type .eq. 'RAV' ) then
        if( iprint.gt.0 ) then
          if( out.gt.0 ) then
            write(out,*)'Reading in RXY & RYX to form Berdichevsky ',
     &                'average'
          else if( out.eq.0 ) then
            write(  *,*)'Reading in RXY & RYX to form Berdichevsky ',
     &                'average'
          end if
        end if
        BERD = .TRUE.
        type = 'RXY'
      else if( type.eq.'RDE' .or. type.eq.'REG' .or.
     &          type.eq.'REM' .or. type.eq.'REP' ) then
        if( iprint.gt.0 ) then
          if( out.gt.0 ) then
            write(out,*)'Reading in total tensor to form Determinant ',
     &              'average or Egger''s eigenvalue'
          else if( out.eq.0 ) then
            write( *,*)'Reading in total tensor to form Determinant ',
     &              'average or Egger''s eigenvalue'
          end if
        end if
        if( type.eq.'RDE' ) then
          DET = .TRUE.
        elseif( type.eq.'REM')then
          EGGM = .TRUE.
        elseif( type.eq.'REP' )then
          EGGP = .TRUE.
        else
           EGG = .TRUE.
        end if
        type = 'RXX'
      end if

      if( type(1:1).eq.'M' ) then
        MODEL = .TRUE.
      else
        MODEL = .FALSE.
      endif
 
      look = 2
    3 read( ind1, '(a3)', end = 9902 ) typex
      call shiftup( typex )
      if( iprint.ge.10 ) then
        write(*,*) 'MTREAD: line ', typex,' read in loking for type'
      endif
      if( type.ne.typex ) goto 3


c...read in no. of periods: return for nper=0 (no data to read)

      read( ind1,* ) nper

      if( iprint.gt.0 ) then 
        write( *,'(3a,i2)' ) ' Type ', type,
     &                       ' located with nper = ', nper
      end if 

      if( nper.eq.0 ) return


      if( (BERD.or.DET.or.EGG.or.EGGP.or.EGGM)
     &        .and. nper.gt.MAXF ) then
        write( *,* ) 'MTREAD: Number of points too large for ',
     &      ' Berdichevsky or Determinant averaging or Eggers,',
     &      ' MAXF = ', MAXF
        goto 6
      end if
 
      if( MODEL ) then
        do i = 1, nper
          read( ind1,*, end=9904, err=9903 ) period(i), rho(i),
     &                                       pha(i)
          if( period(i).lt.0. ) period(i) = -1./period(i)
          rhomax(i) = rho(i)
          rhomin(i) = rho(i)
          phamax(i) = pha(i)
          phamin(i) = pha(i)
          wrho(i)   = 1.
          wpha(i)   = 1.
        enddo
      else
        do i = 1, nper
          read( ind1,*, end=9904, err=9903 ) period(i), rho(i),
     &      pha(i), rhomax(i), rhomin(i), phamax(i), phamin(i),
     &      wrho(i), wpha(i)
          if( iprint.ge.5 ) then
            write(*,*) period(i), rho(i), pha(i), 
     &                 rhomax(i), rhomin(i), phamax(i), phamin(i),
     &                 wrho(i), wpha(i)
          endif
          if( period(i).lt.0. ) period(i) = -1./period(i)
        enddo
        call mtcheck(nper,period,rho,pha,rhomax,rhomin,
     &                 phamax,phamin,wrho,wpha,9906)
      endif
 
      if( BERD .or. DET .or. EGG .or. EGGP .or. EGGM) then
        if( BERD ) then
          type = 'RYX'
        else 
          type = 'RXY'
        end if
        look = 3
    8   read( ind1, '(a3)', end = 9902 ) typex
        call shiftup( typex )
        if( type .ne. typex ) goto 8
 
        read( ind1, * ) nper
        if( iprint.gt.0 ) then
          write( *,'(3a,i2)' ) ' Type ', type,
     &                          ' located with nper = ', nper
        end if 

        do i = 1, nper
          read( ind1,*, end=9904, err=9903 ) per2(i), rho2(i),
     &      pha2(i), rhomx2(i), rhomn2(i), phamx2(i), phamn2(i),
     &      wrho2(i), wpha2(i)
          if( per2(i).lt.0. ) per2(i) = -1./per2(i)
        enddo
        call mtcheck(nper,per2,rho2,pha2,rhomx2,rhomn2,phamx2,phamn2,
     &         wrho2,wpha2,9906)
 
        if( BERD ) then   
          do 11 i = 1, nper   
            if( period(i).ne.per2(i) ) goto 9905
                          
            if( rho(i).ne.MISDAT .and. rho2(i).ne. MISDAT ) then
              call berdav( period(i), rho(i), pha(i), rho2(i), pha2(i),
     &                     rho(i), pha(i) )
            else
              rho(i) = MISDAT
              pha(i) = MISDAT
            end if
 
            if( rhomax(i).ne.MISDAT .and.rhomx2(i).ne.MISDAT) then
              call berdav( period(i), rhomax(i), phamax(i), rhomx2(i),
     &                     phamx2(i), rhomax(i), phamax(i) )
              call berdav( period(i), rhomin(i), phamin(i), rhomn2(i),
     &                     phamn2(i), rhomin(i), phamin(i) )
            else
              rhomax(i) = MISDAT
              rhomin(i) = MISDAT
              phamax(i) = MISDAT
              phamin(i) = MISDAT
            end if
          
   11     continue
 
          call mtcheck(nper,period,rho,pha,rhomax,rhomin,phamax,
     &         phamin,wrho,wpha,9906)

          type = 'RAV'
 
        else
 
          look = 4
          type = 'RYX'
   13     read( ind1, '(a3)', end = 9902 ) typex
          call shiftup( typex )
          if( type .ne. typex ) goto 13
 
          read( ind1, * ) nper
          if( iprint.gt.0 ) then
            if( out.gt.0 ) then
              write( out, '(a,a,a,i2)' ) ' Type ', type,
     &                             ' located with nper = ', nper
            else if( out.eq.0 ) then
              write(   *, '(a,a,a,i2)' ) ' Type ', type,
     &                             ' located with nper = ', nper
            end if
          end if
 
          do i = 1, nper
            read( ind1,*, end=9904, err=9903 ) per3(i), rho3(i),
     &        pha3(i), rhomx3(i), rhomn3(i), phamx3(i), phamn3(i),
     &        wrho3(i), wpha3(i)
            if( per3(i).lt.0. ) per3(i) = -1./per3(i)
          enddo
          call mtcheck(nper,per3,rho3,pha3,rhomx3,rhomn3,phamx3,
     &            phamn3,wrho3,wpha3,9906)
 
          look = 5
          type = 'RYY'
   16     read( ind1, '(a3)', end = 9902 ) typex
          call shiftup( typex )
          if( type .ne. typex ) goto 16
 
          read( ind1,* ) nper
          if( iprint.gt.0 ) then
              write( *, '(3a,i2)' ) ' Type ', type,
     &                              ' located with nper = ', nper
           endif

          do i = 1, nper
            read( ind1,    *, end=9904, err=9903 ) per4(i), rho4(i),
     &        pha4(i), rhomx4(i), rhomn4(i), phamx4(i), phamn4(i),
     &        wrho4(i), wpha4(i)
            if( per4(i).lt.0. ) per4(i) = -1./per4(i)
          enddo
          call mtcheck(nper,per4,rho4,pha4,rhomx4,rhomn4,phamx4,
     &            phamn4,wrho4,wpha4,9906)
 
          do 19 i = 1, nper
 
            if( (period(i).ne.per2(i)) .or.
     &          (  per2(i).ne.per3(i)) .or.
     &          (  per3(i).ne.per4(i))     ) goto 9905
 
            if(  (rho(i).gt.0.) .and. (rho2(i).gt.0.) .and.
     &            (rho3(i).gt.0.) .and. (rho4(i).gt.0.) ) then
              if( DET ) then
                call detav( period(i), rho(i),  pha(i), 
     &                      rho2(i), pha2(i), rho3(i), pha3(i), 
     &                      rho4(i), pha4(i), rdet, pdet )
              else
                 if(EGGP)then
                    call egg_plus(period(i),rho(i),pha(i),rho2(i),
     &                       pha2(i),rho3(i),pha3(i),rho4(i),
     &                       pha4(i), rdet, pdet )
                 elseif(EGGM)then
                    call egg_minus(period(i),rho(i),pha(i),rho2(i),
     &                       pha2(i),rho3(i),pha3(i),rho4(i),
     &                       pha4(i), rdet, pdet )
                 else
                    call egg1 ( period(i), rho(i),  pha(i), 
     &                      rho2(i), pha2(i), rho3(i), pha3(i), 
     &                      rho4(i), pha4(i), rdet, pdet )
                 endif
              end if

              if(      rdet.le.0.                      .or.
     &            rhomax(i).le.0. .or. rhomin(i).le.0. .or.
     &            rhomx2(i).le.0. .or. rhomn2(i).le.0. .or.
     &            rhomx3(i).le.0. .or. rhomn3(i).le.0. .or.
     &            rhomx4(i).le.0. .or. rhomn4(i).le.0. .or.
     &                 pdet.eq.MISDAT                         .or.
     &            phamax(i).eq.MISDAT .or. phamin(i).eq.MISDAT .or.
     &            phamx2(i).eq.MISDAT .or. phamn2(i).eq.MISDAT .or.
     &            phamx3(i).eq.MISDAT .or. phamn3(i).eq.MISDAT .or.
     &            phamx4(i).eq.MISDAT .or. phamn4(i).eq.MISDAT) then
                  rhomax(i) = MISDAT
                  rhomin(i) = MISDAT
                  phamax(i) = MISDAT
                  phamin(i) = MISDAT
              else
                per = period(i)
                call zconv( 2, zdet,  rdet,  pdet, per )
                call zconv( 2, zxx,  rho(i),  pha(i), per )
                fxx = fzerr( per, rho(i), pha(i), rhomax(i), 
     &                     rhomin(i), phamax(i), phamin(i) )
                call zconv( 2, zxy,  rho2(i),  pha2(i), per )
                fxy = fzerr( per, rho2(i), pha2(i), rhomx2(i), 
     &                     rhomn2(i), phamx2(i), phamn2(i) )
                call zconv( 2, zyx,  rho3(i),  pha3(i), per )
                fyx = fzerr( per, rho3(i), pha3(i), rhomx3(i), 
     &                     rhomn3(i), phamx3(i), phamn3(i) )
                call zconv( 2, zyy,  rho4(i),  pha4(i), per )
                fyy = fzerr( per, rho4(i), pha4(i), rhomx4(i), 
     &                     rhomn4(i), phamx4(i), phamn4(i) )
                fzdet = 
     &    (fxx*cabs(zyy)+fyy*cabs(zxx)+fxy*cabs(zyx)+fyx*cabs(zyy))/
     &              (2.*cabs(zdet))
                rhomax(i) = rdet * (1.+(2.*fzdet))
                rhomin(i) = rdet / (1.+(2.*fzdet))
                phamax(i) = pdet + atand(fzdet)
                phamin(i) = pdet - atand(fzdet)
              end if

              rho(i) = rdet
              pha(i) = pdet
            else
              rho(i)    = MISDAT
              pha(i)    = MISDAT
              rhomax(i) = MISDAT
              rhomin(i) = MISDAT
              phamax(i) = MISDAT
              phamin(i) = MISDAT
              wrho(i)   = MISDAT
              wpha(i)   = MISDAT
            end if

   19     continue
 
          call mtcheck(nper,period,rho,pha,rhomax,rhomin,phamax,
     &         phamin,wrho,wpha,9906)

          if( DET ) then
            type = 'RDE'
          elseif(EGGP)then
            type = 'REP'
          elseif(EGGM)then
            type = 'REM'
          else
            type = 'REG'
          end if


        end if
 
      end if
 
c      if( fin.ne.'*' ) close( unit=ind1 )

   20 if( iprint.gt.0 ) then
          write( *,* ) 'MTREAD: successful completion'
      endif
      return
 
 9901 write( *,* ) 'MTREAD: error opening file -- correct name?'//
     &             ' iostat=', ioerr
      call IO_error(fin,ioerr)
      goto 1
 
 9902 if( iprint.gt.0 ) then
        write( *,* ) 'MTREAD: EOF encountered for stat=',stat, 
     &               ' type=',type, '-- rewind made'
      end if
      ilook = ilook+1
      if(ilook.eq.4)then
        nper = -2
        return 1
      end if
      rewind ind1
      goto( 2, 3, 8, 13, 16 ), look
 
 9903 write( *,* ) 'MTREAD: error during read, i = ', i
      nper = -2
      return 1
 
 9904 write( *,* ) 'MTREAD: EOF encountered during read, i = ', i
      nper = -2
      return 1
 
 9905 write( *,* ) 'MTREAD: erroneous sequence of periods for ',
     &                ' average determination, i =', i
      nper = -2
      return 1
      
 9906 write( *,* ) 'MTREAD: error in mtcheck'
      nper = -2
      return 1

      end           
